@@ -78,6 +78,10 @@ iBool isAlphaNumeric_Char(iChar d) {
     return uc_is_alnum(d) ? iTrue : iFalse;
 }
 
+iBool isPunct_Char(iChar d) {
+    return uc_is_punct(d) ? iTrue : iFalse;
+}
+
 void setLocaleCharSet_String(const char *charSet) {
     const size_t n = sizeof(localeCharSet_);
     strncpy(localeCharSet_, charSet, n);
@@ -386,6 +390,24 @@ size_t length_String(const iString *d) {
     return u8_mbsnlen((const uint8_t *) cstr_String(d), size_String(d));
 }
 
+iBool isUtf8_Rangecc(iRangecc d) {
+    return u8_check((const uint8_t *) d.start, size_Range(&d)) == NULL;
+}
+
+size_t length_Rangecc(const iRangecc d) {
+    /*
+    size_t n = 0;
+    for (const char *i = d.start; i < d.end; ) {
+        iChar ch;
+        const int chLen = decodeBytes_MultibyteChar(i, d.end, &ch);
+        if (chLen <= 0) break;
+        i += chLen;
+        n++;
+    }
+    return n;*/
+    return u8_mbsnlen((const uint8_t *) d.start, size_Range(&d));
+}
+
 size_t size_String(const iString *d) {
     return d ? size_Block(&d->chars) : 0;
 }
@@ -462,12 +484,22 @@ iStringList *split_String(const iString *d, const char *separator) {
 }
 
 iString *urlEncodeExclude_String(const iString *d, const char *excluded) {
+    iString *enc = maybeUrlEncodeExclude_String(d, excluded);
+    return enc ? enc : copy_String(d);
+}
+
+iString *urlEncode_String(const iString *d) {
+    return urlEncodeExclude_String(d, "");
+}
+
+iString *maybeUrlEncodeExclude_String(const iString *d, const char *excluded) {
+    /* TODO: Return NULL if nothing to encode. */    
     iString *encoded = new_String();
     /* Note: Any UTF-8 code points are encoded as multiple %NN sequences. */
     for (const char *i = constBegin_String(d), *end = constEnd_String(d); i != end; ++i) {
         char ch = *i;
         if ((ch >= 'A' && ch <= 'Z') || (ch >= 'a' && ch <= 'z') || (ch >= '0' && ch <= '9') ||
-             ch == '-' || ch == '_' || ch == '.' || ch == '~' || strchr(excluded, ch)) {
+            ch == '-' || ch == '_' || ch == '.' || ch == '~' || strchr(excluded, ch)) {
             appendData_Block(&encoded->chars, i, 1);
         }
         else {
@@ -477,11 +509,7 @@ iString *urlEncodeExclude_String(const iString *d, const char *excluded) {
             appendCStrN_String(encoded, escaped, 3);
         }
     }
-    return encoded;
-}
-
-iString *urlEncode_String(const iString *d) {
-    return urlEncodeExclude_String(d, "");
+    return encoded;    
 }
 
 static int fromHex_(char ch) {
@@ -495,7 +523,10 @@ iString *urlDecode_String(const iString *d) {
     return urlDecodeExclude_String(d, "");
 }
 
-iString *urlDecodeExclude_String(const iString *d, const char *excluded) {
+iString *maybeUrlDecodeExclude_String(const iString *d, const char *excluded) {
+    if (indexOf_String(d, '%') == iInvalidPos) {
+        return NULL;
+    }
     iString *decoded = new_String();
     for (const char *i = constBegin_String(d), *end = constEnd_String(d); i != end; ++i) {
         if (*i == '%' && i + 3 <= end) {
@@ -511,7 +542,12 @@ iString *urlDecodeExclude_String(const iString *d, const char *excluded) {
         }
         appendData_Block(&decoded->chars, i, 1);
     }
-    return decoded;
+    return decoded;    
+}
+
+iString *urlDecodeExclude_String(const iString *d, const char *excluded) {
+    iString *dec = maybeUrlDecodeExclude_String(d, excluded);
+    return dec ? dec : copy_String(d);
 }
 
 iChar first_String(const iString *d) {
@@ -546,13 +582,26 @@ iBlock *toUtf16_String(const iString *d) {
                               size_String(d),
                               NULL,
                               &len);
-    // Make it null-terminated.
+    /* Make it null-terminated. */
     const size_t bytes = 2 * len;
     u16 = realloc(u16, bytes + 2);
     u16[len] = 0;
     return newPrealloc_Block(u16, bytes, bytes + 2);
 }
 
+iBlock *toUnicode_String(const iString *d) {
+    size_t len = 0;
+    uint32_t *u32 = u8_to_u32((const uint8_t *) cstr_String(d),
+                              size_String(d),
+                              NULL,
+                              &len);
+    /* Make it null-terminated. */
+    const size_t bytes = 4 * len;
+    u32 = realloc(u32, bytes + 4);
+    u32[len] = 0;
+    return newPrealloc_Block(u32, bytes, bytes + 4);
+}
+
 int cmpSc_String(const iString *d, const char *cstr, const iStringComparison *sc) {
     return sc->cmp(constData_Block(&d->chars), cstr);
 }
@@ -794,6 +843,9 @@ iStringList *split_Rangecc(const iRangecc d, const char *separator) {
 }
 
 int toInt_String(const iString *d) {
+    if (startsWith_String(d, "0x") || startsWith_String(d, "0X")) {
+        return strtol(cstr_String(d), NULL, 16);
+    }
     return atoi(cstr_String(d));
 }
 
@@ -805,6 +857,105 @@ double toDouble_String(const iString *d) {
     return strtod(cstr_String(d), NULL);
 }
 
+iString *quote_String(const iString *d, iBool numericUnicode) {
+    iString *quot = new_String();
+    iConstForEach(String, i, d) {
+        const iChar ch = i.value;
+        if (ch == '"') {
+            appendCStr_String(quot, "\\\"");
+        }
+        else if (ch == '\\') {
+            appendCStr_String(quot, "\\\\");
+        }
+        else if (ch == '\n') {
+            appendCStr_String(quot, "\\n");
+        }
+        else if (ch == '\r') {
+            appendCStr_String(quot, "\\r");
+        }
+        else if (ch == '\t') {
+            appendCStr_String(quot, "\\t");
+        }
+        else if (numericUnicode && ch >= 0x80) {
+            if ((ch >= 0xD800 && ch < 0xE000) || ch >= 0x10000) {
+                /* TODO: Add a helper function? */
+                /* UTF-16 surrogate pair */
+                iString *chs = newUnicodeN_String(&ch, 1);
+                iBlock *u16 = toUtf16_String(chs);
+                delete_String(chs);
+                const uint16_t *ch16 = constData_Block(u16);
+                appendFormat_String(quot, "\\u%04x\\u%04x", ch16[0], ch16[1]);
+            }
+            else {
+                appendFormat_String(quot, "\\u%04x", ch);
+            }
+        }
+        else {
+            appendChar_String(quot, ch);
+        }
+    }
+    return quot;
+}
+
+iString *unquote_String(const iString *d) {
+    iString *unquot = new_String();
+    iConstForEach(String, i, d) {
+        const iChar ch = i.value;
+        if (ch == '\\') {
+            next_StringConstIterator(&i);
+            const iChar esc = i.value;
+            if (esc == '\\') {
+                appendChar_String(unquot, esc);
+            }
+            else if (esc == 'n') {
+                appendChar_String(unquot, '\n');
+            }
+            else if (esc == 'r') {
+                appendChar_String(unquot, '\r');
+            }
+            else if (esc == 't') {
+                appendChar_String(unquot, '\t');
+            }
+            else if (esc == '"') {
+                appendChar_String(unquot, '"');
+            }
+            else if (esc == 'u') {
+                char digits[5];
+                iZap(digits);
+                for (size_t j = 0; j < 4; j++) {
+                    next_StringConstIterator(&i);
+                    digits[j] = *i.pos;
+                }
+                uint16_t ch16[2] = { strtoul(digits, NULL, 16), 0 };
+                if (ch16[0] < 0xD800 || ch16[0] >= 0xE000) {
+                    appendChar_String(unquot, ch16[0]);
+                }
+                else {
+                    /* UTF-16 surrogate pair */
+                    next_StringConstIterator(&i);
+                    next_StringConstIterator(&i);
+                    iZap(digits);
+                    for (size_t j = 0; j < 4; j++) {
+                        next_StringConstIterator(&i);
+                        digits[j] = *i.pos;
+                    }
+                    ch16[1] = strtoul(digits, NULL, 16);
+                    iString *u16 = newUtf16N_String(ch16, 2);
+                    append_String(unquot, u16);
+                    delete_String(u16);
+                }
+            }
+            else {
+                iAssert(0);
+            }
+        }
+        else {
+            appendChar_String(unquot, ch);
+        }
+    }
+    return unquot;
+}
+
 const char *skipSpace_CStr(const char *cstr) {
     while (*cstr && isspace((int) *cstr)) {
         cstr++;
